==> okteta-14.12.3.tar.xz: okteta-14.12.3/designer/oktetawidgetdesignerfactorycollection.h <==
/*
    This file is part of the Okteta Designer plugin, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef OKTETAWIDGETDESIGNERFACTORYCOLLECTION_H
#define OKTETAWIDGETDESIGNERFACTORYCOLLECTION_H

// Qt
#include <QtDesigner/QDesignerCustomWidgetCollectionInterface>
#include <QtCore/QObject>


class OktetaWidgetDesignerFactoryCollection : public QObject,
                                              public QDesignerCustomWidgetCollectionInterface
{
  Q_OBJECT
  Q_INTERFACES(
    QDesignerCustomWidgetCollectionInterface
  )

  Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QDesignerCustomWidgetInterface")

  public:
    explicit OktetaWidgetDesignerFactoryCollection( QObject* parent = 0 );

  public: // QDesignerCustomWidgetCollectionInterface API
    virtual QList<QDesignerCustomWidgetInterface*> customWidgets() const;

  private:
    QList<QDesignerCustomWidgetInterface*> mWidgetFactories;
};

#endif

==> okteta_15.12.3.orig.tar.xz: okteta-15.12.3/designer/oktetawidgetdesignerfactorycollection.h <==
/*
    This file is part of the Okteta Designer plugin, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef OKTETAWIDGETDESIGNERFACTORYCOLLECTION_H
#define OKTETAWIDGETDESIGNERFACTORYCOLLECTION_H

// Qt
#include <QDesignerCustomWidgetCollectionInterface>
#include <QObject>


class OktetaWidgetDesignerFactoryCollection : public QObject,
                                              public QDesignerCustomWidgetCollectionInterface
{
  Q_OBJECT
  Q_INTERFACES(
    QDesignerCustomWidgetCollectionInterface
  )

  Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QDesignerCustomWidgetInterface")

  public:
    explicit OktetaWidgetDesignerFactoryCollection( QObject* parent = 0 );

  public: // QDesignerCustomWidgetCollectionInterface API
    virtual QList<QDesignerCustomWidgetInterface*> customWidgets() const;

  private:
    QList<QDesignerCustomWidgetInterface*> mWidgetFactories;
};

#endif
